AtlThunk

Struct AtlThunk 

pub struct AtlThunk { /* private fields */ }
Rust wrapper of ATL thunk type. It is used as a window procedure with associated data.

Implementations

Source

impl AtlThunk

pub fn try_new() -> Result<Self>

Creates a new AtlThunk object. For more information, see document for AtlThunk_AllocateData.

pub fn try_new_with( window_procedure: unsafe extern "system" fn(HWND, u32, WPARAM, LPARAM) -> LRESULT, first_parameter: HWND, ) -> Result<Self>

Creates a new AtlThunk object from specified window procedure and associated first parameter value. For more information, see document for AtlThunk_AllocateData and AtlThunk_InitData.

pub fn as_window_procedure( &self, ) -> unsafe extern "system" fn(HWND, u32, WPARAM, LPARAM) -> LRESULT

Returns a wrapped window procedure. The returned function pointer is only valid if the following conditions are met:

For more information, see document for AtlThunk_DataToCode.

pub fn set_data( &mut self, window_procedure: unsafe extern "system" fn(HWND, u32, WPARAM, LPARAM) -> LRESULT, first_parameter: HWND, )

Updates the associated window procedure and data. For more information, see document for AtlThunk_InitData.