Struct atl_thunk::AtlThunk

source ·
pub struct AtlThunk { /* private fields */ }
Rust wrapper of ATL thunk type. It is used as a window procedure with associated data.

Implementations

source

impl AtlThunk

source

pub fn try_new( procedure: unsafe extern "system" fn(_: usize, _: u32, _: WPARAM, _: LPARAM) -> LRESULT, first_parameter: usize, ) -> Result<Self>

Creates a new AtlThunk object.

source

pub fn as_raw_window_procedure( &self, ) -> unsafe extern "system" fn(_: HWND, _: u32, _: WPARAM, _: LPARAM) -> LRESULT

Returns a wrapped window procedure. The returned function pointer is only valid before the corresponding AtlThunk object drops.

source

pub fn set_data( &mut self, procedure: unsafe extern "system" fn(_: usize, _: u32, _: WPARAM, _: LPARAM) -> LRESULT, first_parameter: usize, )

Updates the associated window procedure and data.